`lh()` calculates the electoral disproportionality between votes and
seats as proposed by Loosemore and Hanby (1971).
Usage
lh(x, y)
Value
If the input is a proportion the result is between 0 and 1.
But if the input is a percentage it is between 0 and 100.
In both cases the higher the value, the more disproportional the electoral system is.
Arguments
x
(numeric). Numeric vector with the vote share of parties
y
(numeric). Numeric vector with the seat share of parties
References
Loosemore, J., & Hanby, V. (1971). The Theoretical Limits of Maximum Distortion: Some Analytic Expressions for Electoral Systems. British Journal of Political Science, 1(4), 467-477. doi:10.1017/S000712340000925X