`volatility()` calculates electoral volatility index developed by Perdersen (1979).
Usage
volatility(x, y)
Value
If the input is a proportion the result is between 0 and 1.
But if the input is a percentage it is between 0 and 100.
In both cases the higher the value the more volatile is the electoral system.
Arguments
x
(numeric). Numeric vector with the vote share for selected parties in a given election in t.
y
(numeric). Numeric vector with the vote share for selected parties in the t+1 election.
References
Pedersen, M. N. (1979). The dynamics of European party systems: changing patterns of electoral volatility. European journal of political research, 7(1), 1-26.