`fractionalization()` calculates the rate of electoral fractionalization according to
Douglas Rae's (1968) formula.
Usage
fractionalization(x)
Value
Returns a numerical vector with the estimate of party fractionalization.
The result of the index is a value between 0 and 1.
The closer to zero, the lower the fractionalization; the closer to 1, the higher the fractionalization.
Arguments
x
(numeric). A numeric vector in the form of a proportion of votes or seats. The vector should range from 0 to 1.
References
Rae, D. (1968). A note on the fractionalization of some European party systems. Comparative Political Studies, 1(3), 413-418.