`lsq()` calculates the electoral disproportionality between votes and
seats by Least squares index method as proposed by Michael Gallagher.
Usage
lsq(x, y)
Value
If the input is a proportion the result is between 0 and 1.
But if the input is a percentage it is between 0 and 100.
In both cases the higher the value, the more disproportional the electoral system is.
Arguments
x
(numeric). Numeric vector with the vote share of parties
y
(numeric). Numeric vector with the seat share of parties
References
Gallagher, M. (1991). Proportionality, disproportionality and electoral systems. Electoral studies, 10(1), 33-51.