`nationalization()` calculates the Party Nationalization Index as proposed by Jones e Mainwaring (2003).
Usage
nationalization(x)
Value
The result of the index is a value between 0 and 1.
A high score indicates a high level of nationalization
Arguments
x
(numeric). A numeric vector with the vote share for a given party x in each electoral district.
References
Jones, M. P., & Mainwaring, S. (2003). The Nationalization of Parties and Party Systems: An Empirical Measure and an Application to the Americas. Party Politics, 9(2), 139–166. https://doi.org/10.1177/13540688030092002